@@ -3,6 +3,7 @@ import sys
 from websharecli import api
 from websharecli.config import CONFIG
 from websharecli.data import File, filter_unique, filter_extensions, filter_exclude
+from websharecli.terminal import T
 
 
 def _get_link(files, query=None, ignore_vip=False):
@@ -12,9 +13,7 @@ def _get_link(files, query=None, ignore_vip=False):
             link = api.file_link(file_.ident, ignore_vip=ignore_vip)
         except api.LinkUnavailableException:
             if query is not None:
-                print(
-                    '{query} SKIP: {name}'.format(
-                        query=query, name=file_.name), file=sys.stderr)
+                print(f'{query} {T.yellow}SKIP{T.normal}: {file_.name}', file=sys.stderr)
             continue
         else:
             return link, file_
@@ -25,21 +24,23 @@ def download(query, verbose=False, exclude=None, ignore_vip=False):
     """Get download link(s) for files that match the search query"""
     results = []
     not_found = 0
-    for q in query_complete_wildcard(query):
-        files = search(q, limit=3, exclude=exclude)
-        link, file_ = _get_link(files, query=q, ignore_vip=ignore_vip)
-        if link is not None:
-            not_found = 0
-            results.append(link)
-            print('{query} OK: {name}'.format(
-                query=q, name=file_.name), file=sys.stderr)
-        else:
-            not_found += 1
-            print('{query} NOT FOUND'.format(query=q), file=sys.stderr)
-            if not_found >= 3:
-                if verbose:
-                    print('Aborting after 3 failures', file=sys.stderr)
-                break
+    try:
+        for q in query_complete_wildcard(query):
+            files = search(q, limit=3, exclude=exclude)
+            link, file_ = _get_link(files, query=q, ignore_vip=ignore_vip)
+            if link is not None:
+                not_found = 0
+                results.append(link)
+                print(f'{q} {T.green}OK{T.normal}: {file_.name}', file=sys.stderr)
+            else:
+                not_found += 1
+                print(f'{q} {T.red}NOT FOUND{T.normal}', file=sys.stderr)
+                if not_found >= 3:
+                    if verbose:
+                        print('Aborting after 3 failures', file=sys.stderr)
+                    break
+    except KeyboardInterrupt:
+        pass
     return results
 
 
@@ -90,5 +91,4 @@ def query_complete_wildcard(query):
     """Find asterisk ('*') and replace with numbers from 00 to 99"""
     if '*' not in query:
         return [query]
-    return ['{}'.format(
-        query.replace('*', '{:02d}'.format(i))) for i in range(100)]
+    return [query.replace('*', f'{i:02d}') for i in range(100)]
